@@ -78,7 +78,8 @@ log_message("python_version_matches = %r", python_version_matches)
 
 if python_prefix_matches and python_version_matches:
 
-    config_file = os.environ.get("FAST_CONFIG_FILE", None)
+    # config_file = os.environ.get("FAST_CONFIG_FILE", None)
+    config_file = os.environ.get("FastTrackerConfigPath", None)
     environment = os.environ.get("FAST_ENVIRONMENT", None)
 
     log_message("initialize_agent = %r", bool(config_file))
@@ -100,11 +101,14 @@ if python_prefix_matches and python_version_matches:
 
     # 探针初始化
     try:
+        log_message("agent start import")
         from fast_tracker import agent, config
 
+        log_message("agent init start")
         # config.init(collector="127.0.0.1:8111", service="as you wish")
         config.init(collector="fluent-bit:5140", service="as you wish")
         agent.start()
+        log_message("agent init end")
     except BaseException as e:
         log_message("发生错误了，错误信息是: %s", e)
         print("发生错误了，错误信息是", e)
